/**
*****************************************************************************
**
**  File        : serial_io.c
**
**  Abstract    : System Workbench functions to set the serial port as
**  			  characters input/output
**
**  Environment : System Workbench for MCU
**
**  Distribution: The file is distributed as is, without any warranty
**                of any kind.
**
**  (c)Copyright System Workbench for MCU.
**  You may use this file as-is or modify it according to the needs of your
**  project. Distribution of this file (unmodified or modified) is not
**  permitted. System Workbench for MCU permit registered System Workbench(R) users the
**  rights to distribute the assembled, compiled & linked contents of this
**  file as part of an application binary file, provided that it is built
**  using the System Workbench for MCU toolchain.
**
*****************************************************************************
*/

$(include)

#include "serial_io.h"

int __io_putchar(int ch) __attribute__((weak, alias ("__serial_io_putchar")));
int __io_getchar(void) __attribute__((weak, alias ("__serial_io_getchar")));

/* UART handler declaration */
UART_HandleTypeDef UartHandle;

void __serial_io_init() {
	/*## Configure the UART peripheral ##############################*/
	/* Put the USART peripheral in the Asynchronous mode (UART Mode) */
	/* UART configured as follow:
	    - BaudRate = 115200 baud
	    - Word Length = 8 Bits
	    - Stop Bit = One Stop bit
	    - Parity = none
	    - Hardware flow control disabled (RTS and CTS signals) */

	UartHandle.Init.BaudRate   = 115200;
	UartHandle.Init.WordLength = UART_WORDLENGTH_8B;
	UartHandle.Init.StopBits   = UART_STOPBITS_1;
	UartHandle.Init.Parity     = UART_PARITY_NONE;
	UartHandle.Init.HwFlowCtl  = UART_HWCONTROL_NONE;
	UartHandle.Init.Mode       = UART_MODE_TX_RX;

	BSP_COM_Init(COM1, &UartHandle);

	// This is just to keep Eclipse happy, but generates no code; without this
	// Eclipse will generate an "unused" warning for the weak declarations above.
	if (0) __io_putchar(__io_getchar());
}


int __serial_io_putchar(int ch)
{
	/* Write a character to the EVAL_COM1 and Loop until transmitted */
	HAL_UART_Transmit(&UartHandle, (uint8_t *)&ch, 1, HAL_MAX_DELAY);
   	return ch;
}

int __serial_io_getchar(void)
{
	int ch;
	/* Read a character from the EVAL_COM1 and Loop until received */
	HAL_UART_Receive(&UartHandle, (uint8_t *)&ch, 1, HAL_MAX_DELAY);
   	return ch;
}
